# pynaco [![Build Status](https://github.com/unt-libraries/pynaco/actions/workflows/test.yml/badge.svg?branch=master)](https://github.com/unt-libraries/pynaco/actions) [![PyPI Version](https://img.shields.io/pypi/v/pynaco.svg)](https://pypi.python.org/pypi/pynaco)
Python Implementation of NACO Normalization Rules

# Installation

```sh
$ pip install pynaco
```

# Background
This repository is a fork of the sample code found on the OCLC Research Website. 
http://www.oclc.org/research/themes/data-science/naco.html

The goal of this fork is to bring this package into pep8 compliance, add a suite of 
tests and to make it easier to deploy in a variety of settings.

We thank OCLC research for making this available under an Open-Source License.

